@@ -1,4 +1,8 @@
+#if defined(TARGET_OS_HARMATTAN) || defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
+#include <GLES/gl.h>
+#else
 #include <GL/gl.h>
+#endif
 
 #include "blur.hpp"
 #include "foreach.hpp"
