@@ -2,7 +2,7 @@
 #define COLOR_UTILS_HPP_INCLUDED
 
 #include "SDL.h"
-#ifdef TARGET_PANDORA
+#if defined(TARGET_OS_HARMATTAN) || defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
 #include <GLES/gl.h>
 #else
 #include <GL/gl.h>
