@@ -2,6 +2,14 @@
 #define CONTROLS_HPP_INCLUDED
 
 #include <vector>
+#include <cstddef>
+
+//#include <SDL.h>
+//#if SDL_VERSION_ATLEAST(1,3,0)
+//#include <SDL_keycode.h>
+//#else
+#include <SDL_keysym.h>
+//#endif
 
 namespace controls {
 
@@ -16,6 +24,9 @@ enum CONTROL_ITEM {
 	NUM_CONTROLS,
 };
 
+void set_sdlkey (CONTROL_ITEM item, SDLKey key);
+SDLKey get_sdlkey (CONTROL_ITEM item);
+
 void new_level(int starting_cycle, int nplayers, int local_player);
 
 //an object which can lock controls into a specific state for the duration
@@ -27,8 +38,10 @@ public:
 };
 
 void read_local_controls();
+void ignore_current_keypresses();
 
 void get_control_status(int cycle, int player, bool* output);
+void set_delay(int delay);
 
 void read_control_packet(const char* buf, size_t len);
 void write_control_packet(std::vector<char>& v);
@@ -44,6 +57,8 @@ int cycles_behind();
 int their_highest_confirmed();
 int last_packet_size();
 
+void set_checksum(int cycle, int sum);
+
 void debug_dump_controls();
 
 }
