@@ -2,7 +2,7 @@
 #include "custom_object_callable.hpp"
 
 namespace {
-std::vector<custom_object_callable::entry>& entries() {
+std::vector<custom_object_callable::entry>& global_entries() {
 	static std::vector<custom_object_callable::entry> instance;
 	return instance;
 }
@@ -25,12 +25,16 @@ custom_object_callable::custom_object_callable()
 
 	static const std::string CustomObjectProperties[] = {
 	"consts", "type", "active",
-	"time_in_animation", "time_in_animation_delta", "level", "animation",
-	"hitpoints", "max_hitpoints", "mass", "label", "x", "y", "z", "zorder",
+	"time_in_animation", "time_in_animation_delta", "level",
+	"animation", "available_animations",
+	"hitpoints", "max_hitpoints", "mass", "label", "x", "y", "xy", "z",
+	"relative_x", "relative_y", "parent", "pivot", "zorder", "zsub_order",
 	"previous_y", "x1", "x2", "y1", "y2", "w", "h", "midpoint_x", "midpoint_y",
 	"solid_rect", "img_w", "img_h", "front", "back", "cycle", "facing",
 	"upside_down", "up", "down", "velocity_x", "velocity_y",
-	"accel_x", "accel_y", "vars", "tmp", "group", "rotate", "me", "self",
+	"accel_x", "accel_y", "gravity_shift", "platform_motion_x",
+	"registry", "globals", "vars", "tmp", "group", "rotate",
+	"me", "self",
 	"red", "green", "blue", "alpha", "text_alpha", "damage", "hit_by",
 	"distortion", "is_standing", "near_cliff_edge", "distance_to_cliff",
 	"slope_standing_on", "underwater", "water_bounds", "water_object",
@@ -40,8 +44,9 @@ custom_object_callable::custom_object_callable()
 	"attached_objects", "call_stack", "lights",
 	"solid_dimensions_in", "solid_dimensions_not_in",
 	"collide_dimensions_in", "collide_dimensions_not_in",
-	"brightness", "current_generator", "tags", "draw_area", "activation_area",
-	"always_active", "fall_through_platforms", "has_feet",
+	"brightness", "current_generator", "tags", "draw_area", "scale",
+	"activation_area", "clip_area",
+	"always_active", "activation_border", "fall_through_platforms", "has_feet",
 	"x_schedule", "y_schedule", "rotation_schedule", "schedule_speed",
 	"platform_area",
 	"ctrl_up", "ctrl_down", "ctrl_left", "ctrl_right",
@@ -49,15 +54,17 @@ custom_object_callable::custom_object_callable()
 };
 	ASSERT_EQ(NUM_CUSTOM_OBJECT_PROPERTIES, sizeof(CustomObjectProperties)/sizeof(*CustomObjectProperties));
 
-	if(entries().empty()) {
+	if(global_entries().empty()) {
 		for(int n = 0; n != sizeof(CustomObjectProperties)/sizeof(*CustomObjectProperties); ++n) {
-			entries().push_back(entry(CustomObjectProperties[n]));
+			global_entries().push_back(entry(CustomObjectProperties[n]));
 		}
 
-		for(int n = 0; n != entries().size(); ++n) {
-			keys_to_slots()[entries()[n].id] = n;
+		for(int n = 0; n != global_entries().size(); ++n) {
+			keys_to_slots()[global_entries()[n].id] = n;
 		}
 	}
+
+	entries_ = global_entries();
 }
 
 int custom_object_callable::get_key_slot(const std::string& key)
@@ -77,18 +84,18 @@ int custom_object_callable::get_slot(const std::string& key) const
 
 game_logic::formula_callable_definition::entry* custom_object_callable::get_entry(int slot)
 {
-	if(slot < 0 || slot >= entries().size()) {
+	if(slot < 0 || slot >= entries_.size()) {
 		return NULL;
 	}
 
-	return &entries()[slot];
+	return &entries_[slot];
 }
 
 const game_logic::formula_callable_definition::entry* custom_object_callable::get_entry(int slot) const
 {
-	if(slot < 0 || slot >= entries().size()) {
+	if(slot < 0 || slot >= entries_.size()) {
 		return NULL;
 	}
 
-	return &entries()[slot];
+	return &entries_[slot];
 }
