@@ -36,6 +36,7 @@
 #include "raster_distortion.hpp"
 #include "sound.hpp"
 #include "speech_dialog.hpp"
+#include "stats.hpp"
 #include "string_utils.hpp"
 #include "text_entry_widget.hpp"
 #include "thread.hpp"
@@ -105,6 +106,16 @@ FUNCTION_DEF(time, 0, 0, "time() -> timestamp: returns the current real time")
 	time(&t1);
 	return variant(t1);
 END_FUNCTION_DEF(time)
+	
+FUNCTION_DEF(report_, 4, 4, "report() -> boolean: Write a key and a value into [custom] in the stats.")
+		level* lvl = args()[0]->evaluate(variables).convert_to<level>();
+		entity_ptr obj = args()[1]->evaluate(variables).convert_to<entity>();
+		const std::string key = args()[2]->evaluate(variables).as_string();
+		const std::string value = args()[3]->evaluate(variables).as_string();
+		//std::cerr << "Reporting '" << key << "' at '" << value << "' in " << lvl->id() << ".\n";
+		stats::record_event(lvl -> id(), stats::record_ptr(new stats::custom_record(key, value, obj->midpoint())));
+		return variant(true);
+END_FUNCTION_DEF(report_)
 
 class save_game_command : public entity_command_callable
 {
@@ -462,15 +473,23 @@ FUNCTION_DEF(spawn_player, 4, 5, "spawn_player(string type_id, int midpoint_x, i
 					 true));
 END_FUNCTION_DEF(spawn_player)
 
-FUNCTION_DEF(object, 4, 5, "object(string type_id, int midpoint_x, int midpoint_y, int facing, (optional) map properties) -> object: constructs and returns a new object. Note that the difference between this and spawn is that spawn returns a command to actually place the object in the level. object only creates the object and returns it. It may be stored for later use.")
+FUNCTION_DEF(object, 1, 5, "object(string type_id, int midpoint_x, int midpoint_y, int facing, (optional) map properties) -> object: constructs and returns a new object. Note that the difference between this and spawn is that spawn returns a command to actually place the object in the level. object only creates the object and returns it. It may be stored for later use.")
 	formula::fail_if_static_context();
-
 	const std::string type = args()[0]->evaluate(variables).as_string();
-	const int x = args()[1]->evaluate(variables).as_int();
-	const int y = args()[2]->evaluate(variables).as_int();
-	const bool face_right = args()[3]->evaluate(variables).as_int() > 0;
-	custom_object* obj = new custom_object(type, x, y, face_right);
-
+	custom_object* obj;
+	
+	if(args().size() > 1) {
+		const int x = args()[1]->evaluate(variables).as_int();
+		const int y = args()[2]->evaluate(variables).as_int();
+		const bool face_right = args()[3]->evaluate(variables).as_int() > 0;
+		obj = new custom_object(type, x, y, face_right);
+	} else {
+		const int x = 0;
+		const int y = 0;
+		const bool face_right = true;
+		obj = new custom_object(type, x, y, face_right);
+	}
+		
 	//adjust so the object's x/y is its midpoint.
 	obj->set_pos(obj->x() - obj->current_frame().width() / 2 , obj->y() - obj->current_frame().height() / 2);
 
@@ -750,7 +769,7 @@ private:
 	mutable boost::intrusive_ptr<add_by_slot_command> cmd_;
 };
 
-FUNCTION_DEF(solid, 3, 5, "solid(level, int x, int y, (optional)int w=1, (optional) int h=1) -> boolean: returns true iff the level contains solid space within the given (x,y,w,h) rectangle")
+FUNCTION_DEF(solid, 3, 6, "solid(level, int x, int y, (optional)int w=1, (optional) int h=1, (optional) int debug=0) -> boolean: returns true iff the level contains solid space within the given (x,y,w,h) rectangle. If 'debug' is set, then the tested area will be displayed on-screen.")
 	level* lvl = args()[0]->evaluate(variables).convert_to<level>();
 	const int x = args()[1]->evaluate(variables).as_int();
 	const int y = args()[2]->evaluate(variables).as_int();
@@ -760,6 +779,11 @@ FUNCTION_DEF(solid, 3, 5, "solid(level, int x, int y, (optional)int w=1, (option
 
 	rect r(x, y, w, h);
 
+	if(args().size() >= 6) {
+		//debugging so set the debug rect
+		add_debug_rect(r);
+	}
+
 	return variant(lvl->solid(r));
 END_FUNCTION_DEF(solid)
 
@@ -1091,7 +1115,7 @@ private:
 
 					SDL_Event event;
 					while(SDL_PollEvent(&event)) {
-#if TARGET_IPHONE_SIMULATOR || TARGET_OS_IPHONE
+#if TARGET_IPHONE_SIMULATOR || TARGET_OS_HARMATTAN || TARGET_OS_IPHONE
 						// the user event gets handled the same as pressing escape
 						if (menu_button_.handle_event(event))
 						{
@@ -1112,6 +1136,19 @@ private:
 							}
 						}
 						break;
+#elif TARGET_OS_HARMATTAN
+						// make sure nothing happens while the app is supposed to be "inactive"
+						case SDL_ACTIVEEVENT:
+						if (event.active.state & SDL_APPINPUTFOCUS && event.active.gain == 0)
+						{
+							SDL_Event e;
+							while (SDL_WaitEvent(&e))
+							{
+								if (e.type == SDL_ACTIVEEVENT && e.active.gain == 1)
+									break;
+							}
+						}
+						break;
 #endif
 						case SDL_QUIT:
 							throw interrupt_game_exception();
@@ -1255,6 +1292,18 @@ FUNCTION_DEF(debug, 1, -1, "debug(...): outputs arguments to the console")
 	return variant(new debug_command(str));
 END_FUNCTION_DEF(debug)
 
+FUNCTION_DEF(debug_fn, 2, 2, "debug(msg, expr): evaluates and returns expr. Will print 'msg' to stderr")
+	variant res = args()[1]->evaluate(variables);
+	if(preferences::debug()) {
+		variant msg = args()[0]->evaluate(variables);
+		std::string s = msg.to_debug_string();
+		debug_console::add_message(s);
+		std::cerr << "CONSOLE: " << s << "\n";
+	}
+
+	return res;
+END_FUNCTION_DEF(debug_fn)
+
 #if !TARGET_IPHONE_SIMULATOR && !TARGET_OS_IPHONE
 class debug_console_command : public entity_command_callable
 {
