@@ -329,6 +329,7 @@ custom_object_type::custom_object_type(wml::const_node_ptr node, const custom_ob
 	hitpoints_(wml::get_int(node, "hitpoints", 1)),
 	timer_frequency_(wml::get_int(node, "timer_frequency", -1)),
 	zorder_(wml::get_int(node, "zorder")),
+	zsub_order_(wml::get_int(node, "zsub_order")),
 	is_human_(wml::get_bool(node, "is_human", false)),
 	goes_inactive_only_when_standing_(wml::get_bool(node, "goes_inactive_only_when_standing", false)),
 	dies_on_inactive_(wml::get_bool(node, "dies_on_inactive", false)),
@@ -348,25 +349,27 @@ custom_object_type::custom_object_type(wml::const_node_ptr node, const custom_ob
 	is_vehicle_(wml::get_bool(node, "vehicle", false)),	
 	passenger_x_(wml::get_int(node, "passenger_x")),
 	passenger_y_(wml::get_int(node, "passenger_y")),
-	feet_width_(wml::get_int(node, "feet_width", 5)),
+	feet_width_(wml::get_int(node, "feet_width", 0)),
 	use_image_for_collisions_(wml::get_bool(node, "use_image_for_collisions", false)),
 	has_feet_(wml::get_bool(node, "has_feet", true) && use_image_for_collisions_ == false),
 	adjust_feet_on_animation_change_(wml::get_bool(node, "adjust_feet_on_animation_change", true)),
 	teleport_offset_x_(wml::get_int(node, "teleport_offset_x")),
 	teleport_offset_y_(wml::get_int(node, "teleport_offset_y")),
+	no_move_to_standing_(wml::get_bool(node, "no_move_to_standing")),
+	reverse_global_vertical_zordering_(wml::get_bool(node, "reverse_global_vertical_zordering", false)),
+	serializable_(wml::get_bool(node, "serializable", true)),
 	solid_(solid_info::create(node)),
 	platform_(solid_info::create_platform(node)),
 	has_solid_(solid_ || use_image_for_collisions_),
 	solid_dimensions_(has_solid_ || platform_ ? 0xFFFFFFFF : 0),
 	collide_dimensions_(0xFFFFFFFF),
 	weak_solid_dimensions_(has_solid_ || platform_ ? 0xFFFFFFFF : 0),
-	weak_collide_dimensions_(0xFFFFFFFF)
+	weak_collide_dimensions_(0xFFFFFFFF),
+	activation_border_(wml::get_int(node, "activation_border", 100))
 {
-#if !TARGET_IPHONE_SIMULATOR && !TARGET_OS_IPHONE
 	if(node->get_child("editor_info")) {
 		editor_info_.reset(new editor_entity_info(node->get_child("editor_info")));
 	}
-#endif
 
 	const bool is_variation = base_type != NULL;
 
@@ -441,6 +444,13 @@ custom_object_type::custom_object_type(wml::const_node_ptr node, const custom_ob
 		}
 	}
 
+	std::vector<variant> available_frames;
+	for(frame_map::const_iterator i = frames_.begin(); i != frames_.end(); ++i) {
+		available_frames.push_back(variant(i->first));
+	}
+
+	available_frames_ = variant(&available_frames);
+
 	mass_ = wml::get_int(node, "mass", (default_frame_->collide_w() * default_frame_->collide_h() ) );
 	
 	wml::node::const_child_iterator c1 = node->begin_child("child");
@@ -467,6 +477,10 @@ custom_object_type::custom_object_type(wml::const_node_ptr node, const custom_ob
 		}
 	}
 
+	if(node->has_attr("parallax_scale_x") || node->has_attr("parallax_scale_y")) {
+		parallax_scale_millis_.reset(new std::pair<int, int>(wml::get_int(node, "parallax_scale_x", 1000), wml::get_int(node, "parallax_scale_y", 1000)));
+	}
+	
 	wml::const_node_ptr vars = node->get_child("vars");
 	if(vars) {
 		std::vector<std::string> var_str;
@@ -499,7 +513,7 @@ custom_object_type::custom_object_type(wml::const_node_ptr node, const custom_ob
 		entry->type_definition = entry->type_definition_holder.get();
 	}
 
-	std::cerr << "TMP_VARIABLES: '" << id_ << "' -> " << tmp_variables_.size() << "\n";
+	//std::cerr << "TMP_VARIABLES: '" << id_ << "' -> " << tmp_variables_.size() << "\n";
 
 	consts_.reset(new game_logic::map_formula_callable);
 	wml::const_node_ptr consts = node->get_child("consts");
