@@ -28,7 +28,7 @@
 namespace gui {
 
 dialog::dialog(int x, int y, int w, int h)
-  : opened_(false), cancelled_(false), clear_bg_(true), padding_(10),
+  : opened_(false), cancelled_(false), clear_bg_(196), padding_(10),
     add_x_(0), add_y_(0), bg_alpha_(1.0), last_draw_(-1)
 {
 	set_loc(x,y);
@@ -148,7 +148,7 @@ void dialog::handle_draw() const
 	if(clear_bg()) {
 		SDL_Rect rect = {x(),y(),width(),height()};
 		SDL_Color col = {0,0,0,0};
-		graphics::draw_rect(rect,col,196);
+		graphics::draw_rect(rect,col,clear_bg_);
 
 		//fade effect for fullscreen dialogs
 		if(bg_.valid()) {
