@@ -3,12 +3,15 @@
 
 #include <string>
 
+#include "achievements.hpp"
+
 namespace graphics {
 class color;
 class color_transform;
 }
 
 class entity;
+class rect;
 class level;
 
 struct screen_position {
@@ -30,6 +33,8 @@ screen_position& last_draw_position();
 
 void screen_color_flash(const graphics::color_transform& color, const graphics::color_transform& color_delta, int duration);
 void set_scene_title(const std::string& msg, int duration=150);
+void set_displayed_achievement(achievement_ptr a);
+bool is_achievement_displayed();
 void draw_scene(const level& lvl, screen_position& pos, const entity* focus=NULL, bool do_draw=true);
 
 struct performance_data {
@@ -47,4 +52,6 @@ struct performance_data {
 
 void draw_fps(const level& lvl, const performance_data& data);
 
+void add_debug_rect(const rect& r);
+
 #endif
