@@ -1,6 +1,8 @@
-#ifdef TARGET_PANDORA
+#if defined(TARGET_OS_HARMATTAN) || defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
 #include <GLES/gl.h>
+#ifdef TARGET_PANDORA
 #include <GLES/glues.h>
+#endif
 #else
 #include <GL/gl.h>
 #include <GL/glu.h>
@@ -897,7 +899,7 @@ void editor::edit_level()
 			//remove ghost objects and re-add them. This guarantees ghost
 			//objects always remain at the end of the level ordering.
 			remove_ghost_objects();
-			entity_ptr c = lvl_->get_next_character_at_point(xpos_ + mousex*zoom_, ypos_ + mousey*zoom_);
+			entity_ptr c = lvl_->get_next_character_at_point(xpos_ + mousex*zoom_, ypos_ + mousey*zoom_, xpos_, ypos_);
 			foreach(const entity_ptr& ghost, ghost_objects_) {
 				lvl_->add_character(ghost);
 			}
@@ -940,7 +942,7 @@ void editor::edit_level()
 			//not in object mode, the picker still highlights objects,
 			//though it won't create ghosts, so remove all ghosts.
 			if(tool() == TOOL_PICKER) {
-				entity_ptr c = lvl_->get_next_character_at_point(xpos_ + mousex*zoom_, ypos_ + mousey*zoom_);
+				entity_ptr c = lvl_->get_next_character_at_point(xpos_ + mousex*zoom_, ypos_ + mousey*zoom_, xpos_, ypos_);
 				lvl_->set_editor_highlight(c);
 			} else {
 				lvl_->set_editor_highlight(entity_ptr());
@@ -2178,6 +2180,8 @@ bool editor::confirm_quit()
 
 void editor::save_level()
 {
+	lvl_->set_id(filename_);
+
 	level_changed_ = 0;
 
 	remove_ghost_objects();
@@ -2320,15 +2324,26 @@ void editor::draw() const
 		glDisable(GL_TEXTURE_2D);
 		glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
+		//number of variables seen of each type, used to
+		//cycle through colors for each variable type.
+		std::map<editor_variable_info::VARIABLE_TYPE, int> nseen_variables;
+
 		const editor_variable_info* selected_var = variable_info_selected(property_dialog_->get_entity(), xpos_ + mousex*zoom_, ypos_ + mousey*zoom_, zoom_);
 		foreach(const editor_variable_info& var, property_dialog_->get_entity()->editor_info()->vars()) {
 			const std::string& name = var.variable_name();
 			const editor_variable_info::VARIABLE_TYPE type = var.type();
+			const int color_index = nseen_variables[type]++;
 			variant value = property_dialog_->get_entity()->query_value(name);
 			if(&var == selected_var) {
 				glColor4ub(255, 255, 0, 255);
 			} else {
-				glColor4ub(255, 0, 0, 255);
+				switch(color_index) {
+					case 0: glColor4ub(255, 0, 0, 255); break;
+					case 1: glColor4ub(0, 255, 0, 255); break;
+					case 2: glColor4ub(0, 0, 255, 255); break;
+					case 3: glColor4ub(255, 255, 0, 255); break;
+					default:glColor4ub(255, 0, 255, 255); break;
+				}
 			}
 
 			varray.clear();
