@@ -12,6 +12,9 @@
 #include "level_object.hpp"
 #include "stats.hpp"
 
+static const int EDITOR_MENUBAR_HEIGHT = 40;
+static const int EDITOR_SIDEBAR_WIDTH = 220;
+
 namespace gui {
 class dialog;
 }
@@ -21,6 +24,7 @@ class character_editor_dialog;
 class editor_layers_dialog;
 class group_property_editor_dialog;
 class property_editor_dialog;
+class segment_editor_dialog;
 class tileset_editor_dialog;
 }
 
@@ -111,6 +115,8 @@ public:
 	//switch the current facing.
 	void toggle_facing();
 
+	void duplicate_selected_objects();
+
 	void run_script(const std::string& id);
 
 	//function which gets the expected layer at which a certain tile id appears.
@@ -165,6 +171,7 @@ private:
 
 	//functions which add and remove an object from a level, as well as
 	//sending the object appropriate events.
+	void add_multi_object_to_level(entity_ptr e);
 	void add_object_to_level(entity_ptr e);
 	void remove_object_from_level(entity_ptr e);
 
@@ -199,6 +206,8 @@ private:
 	boost::scoped_ptr<editor_dialogs::property_editor_dialog> property_dialog_;
 	boost::scoped_ptr<editor_dialogs::tileset_editor_dialog> tileset_dialog_;
 
+	boost::scoped_ptr<editor_dialogs::segment_editor_dialog> segment_dialog_;
+
 	gui::dialog* current_dialog_;
 
 	//if the mouse is currently down, drawing a rect.
