@@ -16,7 +16,7 @@
 
 #include "SDL.h"
 
-#if !TARGET_IPHONE_SIMULATOR && !TARGET_OS_IPHONE
+#if !TARGET_IPHONE_SIMULATOR && !TARGET_OS_HARMATTAN && !TARGET_OS_IPHONE
 #include "SDL_ttf.h"
 #endif
 
