@@ -17,6 +17,8 @@
 #include <stdio.h>
 #include <iostream>
 #include <vector>
+#include <limits.h>
+
 
 //#include "foreach.hpp"
 #include "asserts.hpp"
@@ -27,6 +29,7 @@
 #include "formula_constants.hpp"
 #include "formula_function.hpp"
 #include "formula_tokenizer.hpp"
+#include "i18n.hpp"
 #include "map_utils.hpp"
 #include "random.hpp"
 #include "unit_test.hpp"
@@ -35,6 +38,8 @@
 namespace {
 	//the last formula that was executed; used for outputting debugging info.
 	const game_logic::formula* last_executed_formula;
+
+	bool _verbatim_string_expressions = false;
 }
 
 void output_formula_error_info() {
@@ -45,6 +50,9 @@ void output_formula_error_info() {
 
 namespace game_logic
 {
+	void set_verbatim_string_expressions(bool verbatim) {
+		_verbatim_string_expressions = verbatim;
+	}
 	
 	formula_error::formula_error()
 	{
@@ -103,6 +111,11 @@ namespace game_logic
 		values_[key] = value;
 		return *this;
 	}
+
+	variant& map_formula_callable::add_direct_access(const std::string& key)
+	{
+		return values_[key];
+	}
 	
 	variant map_formula_callable::get_value(const std::string& key) const
 	{
@@ -467,7 +480,8 @@ private:
 		if(left.is_list() || left.is_map()) {
 			return left[ key ];
 		} else {
-			std::cerr << "illegal usage of operator []'\n";
+			output_formula_error_info();
+			std::cerr << "illegal usage of operator []: called on " << left.to_debug_string() << " value: " << left_->str() << "'\n";
 			throw formula_error();
 		}
 	}
@@ -475,6 +489,43 @@ private:
 	expression_ptr left_, key_;
 };
 
+class slice_square_bracket_expression : public formula_expression {
+public:
+	slice_square_bracket_expression(expression_ptr left, expression_ptr start, expression_ptr end)
+	: formula_expression("_slice_sqbr"), left_(left), start_(start), end_(end)
+	{}
+private:
+	variant execute(const formula_callable& variables) const {
+		const variant left = left_->evaluate(variables);
+		int begin_index = start_ ? start_->evaluate(variables).as_int()%(left.num_elements()+1) : 0;
+		int end_index = end_ ? end_->evaluate(variables).as_int()%(left.num_elements()+1) : left.num_elements();
+		
+		if(left.is_list()) {
+			if(left.num_elements() == 0) {
+				return variant();
+			}
+			if(end_index >= begin_index) {
+				std::vector<variant> result;
+				result.reserve(end_index - begin_index);
+				while(begin_index != end_index) {
+					result.push_back(left[begin_index++]);
+				}
+				
+				return variant(&result);
+			} else {
+				return variant();
+			}
+			
+		} else {
+			std::cerr << "illegal usage of operator [:]'\n";
+			throw formula_error();
+		}
+	}
+	
+	expression_ptr left_, start_, end_;
+};
+	
+	
 #define OPTIMIZED_INT_BINARY_OP(name, op) \
 class name##_integer_operator_expression : public formula_expression { \
 public: \
@@ -483,7 +534,9 @@ public: \
 	{} \
 private: \
 	variant execute(const formula_callable& variables) const { \
-		return variant(left_->evaluate(variables).as_int() op value_); \
+		variant v = left_->evaluate(variables); \
+		if(v.is_decimal()) { return variant(v op variant(value_)); } \
+		return variant(v.as_int() op value_); \
 	} \
 	expression_ptr left_; \
 	int value_; \
@@ -576,7 +629,7 @@ public:
 			case OP_ADD: return expression_ptr(new add_integer_operator_expression(left_, v.as_int()));
 			case OP_SUB: return expression_ptr(new sub_integer_operator_expression(left_, v.as_int()));
 			case OP_MUL: return expression_ptr(new mul_integer_operator_expression(left_, v.as_int()));
-			case OP_DIV: if(v.as_int() != 0) { return expression_ptr(new div_integer_operator_expression(left_, v.as_int())); }
+			case OP_DIV: if(v.as_int() != 0) { return expression_ptr(new div_integer_operator_expression(left_, v.as_int())); } break;
 			case OP_EQ: return expression_ptr(new eq_integer_operator_expression(left_, v.as_int()));
 			case OP_NEQ: return expression_ptr(new ne_integer_operator_expression(left_, v.as_int()));
 			case OP_LT: return expression_ptr(new lt_integer_operator_expression(left_, v.as_int()));
@@ -624,7 +677,14 @@ private:
 			case OP_MUL: 
 				return left * right;
 			case OP_DIV: 
-				return left / right;
+				//this is a very unorthodox hack to guard against divide-by-zero errors.  It returns positive or negative infinity instead of asserting, which (hopefully!) works out for most of the physical calculations that are using this.  We tentatively view this behavior as much more preferable to the game apparently crashing for a user.  This is of course not rigorous outside of a videogame setting.
+				if(right.as_int() == 0) { 
+					if(left.as_int() > 0){
+						return variant(INT_MAX); 
+					}else{
+						return variant(INT_MIN);
+					}
+				}else{return left / right;}
 			case OP_POW: 
 				return left ^ right;
 			case OP_EQ:  
@@ -741,28 +801,58 @@ private:
 	variant i_;
 };
 
+class decimal_expression : public formula_expression {
+public:
+	explicit decimal_expression(int i, int f) : formula_expression("_decimal"), v_(i*VARIANT_DECIMAL_PRECISION + f, variant::DECIMAL_VARIANT)
+	{}
+private:
+	variant execute(const formula_callable& /*variables*/) const {
+		return v_;
+	}
+	
+	variant v_;
+};
+
 class string_expression : public formula_expression {
 public:
-	explicit string_expression(std::string str) : formula_expression("_string")
+	explicit string_expression(std::string str, bool translate = false) : formula_expression("_string")
 	{
-		std::string::iterator i;
-		while((i = std::find(str.begin(), str.end(), '{')) != str.end()) {
-			std::string::iterator j = std::find(i, str.end(), '}');
-			if(j == str.end()) {
-				break;
+		if (!_verbatim_string_expressions) {
+			size_t pos = 0;
+			//replace \\n sequences with newlines
+			while((pos = str.find("\\n", pos)) != std::string::npos) {
+				str = str.replace(pos, 2, "\n");
 			}
+			pos = 0;
+			//and remove tabs
+			while((pos = str.find("\t", pos)) != std::string::npos) {
+				str = str.replace(pos, 2, "");
+			}
+			if (translate) {
+				str = i18n::tr(str);
+			}
+
+			std::string::iterator i;
+			while((i = std::find(str.begin(), str.end(), '{')) != str.end()) {
+				std::string::iterator j = std::find(i, str.end(), '}');
+				if(j == str.end()) {
+					break;
+				}
 			
-			const std::string formula_str(i+1, j);
-			const int pos = i - str.begin();
-			str.erase(i, j+1);
+				const std::string formula_str(i+1, j);
+				const int pos = i - str.begin();
+				str.erase(i, j+1);
 			
-			substitution sub;
-			sub.pos = pos;
-			sub.calculation.reset(new formula(formula_str));
-			subs_.push_back(sub);
-		}
+				substitution sub;
+				sub.pos = pos;
+				sub.calculation.reset(new formula(formula_str));
+				subs_.push_back(sub);
+			}
 		
-		std::reverse(subs_.begin(), subs_.end());
+			std::reverse(subs_.begin(), subs_.end());
+		} else if (translate) {
+			str = std::string("~") + str + std::string("~");
+		}
 		
 		str_ = variant(str);
 	}
@@ -805,6 +895,7 @@ int operator_precedence(const token& t)
 	static std::map<std::string,int> precedence_map;
 	if(precedence_map.empty()) {
 		int n = 0;
+		precedence_map["->"] = ++n;
 		precedence_map["not"] = ++n;
 		precedence_map["where"] = ++n;
 		precedence_map["or"]    = ++n;
@@ -1036,6 +1127,13 @@ namespace {
 	};
 }
 
+int in_static_context = 0;
+struct static_context {
+	static_context() { ++in_static_context; }
+	~static_context() { --in_static_context; }
+};
+		
+
 expression_ptr optimize_expression(expression_ptr result, function_symbol_table* symbols, const formula_callable_definition* callable_def, bool reduce_to_static)
 {
 	const std::string str = result->str();
@@ -1047,7 +1145,14 @@ expression_ptr optimize_expression(expression_ptr result, function_symbol_table*
 		try {
 			const unsigned int rng_seed = rng::get_seed();
 			formula_callable_ptr static_callable(new static_formula_callable);
-			variant res = result->static_evaluate(*static_callable);
+
+			variant res;
+			
+			{
+				const static_context ctx;
+				res = result->static_evaluate(*static_callable);
+			}
+
 			if(rng_seed == rng::get_seed() && static_callable->refcount() == 1) {
 				//this expression is static. Reduce it to its result.
 				result = expression_ptr(new variant_expression(res));
@@ -1162,7 +1267,7 @@ expression_ptr parse_expression_internal(const token* i1, const token* i2, funct
 			fn_call = NULL;
 		}
 		
-		if(i->type == TOKEN_LPARENS || i->type == TOKEN_LSQUARE) {
+		if(i->type == TOKEN_LPARENS || i->type == TOKEN_LSQUARE || i->type == TOKEN_LBRACKET) {
 			if(i->type == TOKEN_LPARENS && parens == 0 && i != i1) {
 				fn_call = i;
 			} else if(i->type == TOKEN_LSQUARE && parens == 0 && i != i1 && (i-1)->type != TOKEN_OPERATOR && (op == NULL || operator_precedence(*op) >= operator_precedence(*i))) {
@@ -1171,7 +1276,7 @@ expression_ptr parse_expression_internal(const token* i1, const token* i2, funct
 			}
 			
 			++parens;
-		} else if(i->type == TOKEN_RPARENS || i->type == TOKEN_RSQUARE) {
+		} else if(i->type == TOKEN_RPARENS || i->type == TOKEN_RSQUARE || i->type == TOKEN_RBRACKET) {
 			--parens;
 			
 			if(parens == 0 && i+1 != i2) {
@@ -1212,10 +1317,48 @@ expression_ptr parse_expression_internal(const token* i1, const token* i2, funct
 					parse_args(i1+1,i2-1,&args,symbols, callable_def, can_optimize);
 					return expression_ptr(new list_expression(args));
 				} else {
-					//execute operator [ ]
-					return expression_ptr(new square_bracket_expression(
-																		parse_expression(i1,tok,symbols, callable_def, can_optimize),
-																		parse_expression(tok+1,i2-1,symbols, callable_def, can_optimize)));
+					//determine if it's an array-style access of a single list element, or a slice.
+					const token* tok2 = i2-2;
+					int bracket_parens_count = 0;
+					const token* colon_tok = NULL;
+					while (tok2 != tok){
+						if (tok2->type == TOKEN_RSQUARE || tok2->type == TOKEN_RPARENS) {
+							bracket_parens_count++;
+						} else if (tok2->type == TOKEN_LSQUARE || tok2->type == TOKEN_LPARENS){
+							bracket_parens_count--;
+						} else if (tok2->type == TOKEN_COLON){
+							if(bracket_parens_count != 0){
+									//TODO - handle error - mismatching brackets
+									std::cerr << "mismatching brackets or parentheses inside [ ]: '" << std::string((i1+1)->begin, (i2-1)->end) << "'\n";
+							} else if (colon_tok != NULL){
+									//TODO - handle error - more than one colon.
+									std::cerr << "more than one colon inside a slice [:]: '" << std::string((i1+1)->begin, (i2-1)->end) << "'\n";
+							} else {
+								colon_tok = tok2;
+							}
+						}
+						--tok2;	
+					}
+					
+					if(colon_tok != NULL){
+						expression_ptr start, end;
+						if(tok+1 < colon_tok) {
+							start = parse_expression(tok+1, colon_tok, symbols, callable_def, can_optimize);
+						}
+
+						if(colon_tok+1 < i2-1) {
+							end = parse_expression(colon_tok+1, i2-1, symbols, callable_def, can_optimize);
+						}
+
+						//it's a slice.  execute operator [ : ]
+						return expression_ptr(new slice_square_bracket_expression(
+																			parse_expression(i1,tok,symbols, callable_def, can_optimize), start, end));
+					}else{	
+						//execute operator [ ]
+						return expression_ptr(new square_bracket_expression(
+																			parse_expression(i1,tok,symbols, callable_def, can_optimize),
+																			parse_expression(tok+1,i2-1,symbols, callable_def, can_optimize)));
+					}
 				}
 			}
 		} else if(i1->type == TOKEN_LBRACKET && (i2-1)->type == TOKEN_RBRACKET) {
@@ -1240,8 +1383,25 @@ expression_ptr parse_expression_internal(const token* i1, const token* i2, funct
 			} else if(i1->type == TOKEN_INTEGER) {
 				int n = strtol(std::string(i1->begin,i1->end).c_str(), NULL, 0);
 				return expression_ptr(new integer_expression(n));
+			} else if(i1->type == TOKEN_DECIMAL) {
+				char* endptr = NULL;
+				char* enddec = NULL;
+				int n = strtol(std::string(i1->begin,i1->end).c_str(), &endptr, 0);
+				int m = strtol(endptr+1, &enddec, 0);
+				int dist = enddec - endptr;
+				while(dist > 4) {
+					m /= 10;
+					--dist;
+				}
+				while(dist < 4) {
+					m *= 10;
+					++dist;
+				}
+
+				return expression_ptr(new decimal_expression(n, m));
 			} else if(i1->type == TOKEN_STRING_LITERAL) {
-				return expression_ptr(new string_expression(std::string(i1->begin+1,i1->end-1)));
+				bool translate = *(i1->begin) == '~';
+				return expression_ptr(new string_expression(std::string(i1->begin+1,i1->end-1), translate));
 			}
 		} else if(i1->type == TOKEN_IDENTIFIER &&
 				  (i1+1)->type == TOKEN_LPARENS &&
@@ -1348,7 +1508,13 @@ expression_ptr parse_expression_internal(const token* i1, const token* i2, funct
 												  op_name, parse_expression(i1,op,symbols, callable_def, can_optimize),
 												  parse_expression(op+1,i2,symbols, callable_def, can_optimize)));
 }
-		
+}
+
+void formula::fail_if_static_context()
+{
+	if(in_static_context) {
+		throw non_static_expression_exception();
+	}
 }
 	
 formula_ptr formula::create_string_formula(const std::string& str)
@@ -1459,15 +1625,16 @@ formula::formula(const wml::value& val, function_symbol_table* symbols, const fo
 				++begin_line;
 			}
 
-			std::string whitespace;
-			for(int n = 0; n < tok.begin - begin_line; ++n) {
-				whitespace += " ";
-			}
+			std::string whitespace(begin_line, tok.begin);
+			std::fill(whitespace.begin(), whitespace.end(), ' ');
+
+			std::cerr << std::string(begin_line, tok.begin) << "\n";
 
 			ASSERT_LOG(false, "ERROR WHILE PARSING FORMULA AT "
 			  << (filename_ ? *filename_ : "UNKNOWN") << ":"
 			  << (line_ + nline) << " " << error_msg << "\n"
-			  << std::string(begin_line, end_line) << "\n" << "^\n");
+			  << std::string(begin_line, end_line) << "\n"
+			  << whitespace << "^\n");
 		}
 	}
 	
@@ -1525,6 +1692,13 @@ variant formula::execute() const
 	return execute(*null_callable);
 }
 
+UNIT_TEST(formula_slice) {
+	CHECK(formula("myList[2:4] where myList = [1,2,3,4,5,6]").execute() == formula("[3,4]").execute(), "test failed");
+	CHECK(formula("myList[0:2] where myList = [1,2,3,4,5,6]").execute() == formula("[1,2]").execute(), "test failed");
+	CHECK(formula("myList[1:4] where myList = [0,2,4,6,8,10,12,14]").execute() == formula("[2,4,6]").execute(), "test failed");
+}
+	
+	
 UNIT_TEST(formula_in) {
 	CHECK(formula("1 in [4,5,6]").execute() == variant(0), "test failed");
 	CHECK(formula("5 in [4,5,6]").execute() == variant(1), "test failed");
@@ -1559,7 +1733,6 @@ UNIT_TEST(dot_precedence) {
 }
 
 UNIT_TEST(short_circuit) {
-	return;
 	map_formula_callable* callable = new map_formula_callable;
 	variant ref(callable);
 	callable->add("x", variant(0));
@@ -1567,6 +1740,19 @@ UNIT_TEST(short_circuit) {
 	f.execute(*callable);
 }
 
+UNIT_TEST(formula_decimal) {
+	CHECK_EQ(formula("0.0005").execute().string_cast(), "0.000");
+	CHECK_EQ(formula("0.005").execute().string_cast(), "0.005");
+	CHECK_EQ(formula("0.05").execute().string_cast(), "0.050");
+	CHECK_EQ(formula("0.5").execute().string_cast(), "0.500");
+	CHECK_EQ(formula("8.5 + 0.5").execute().string_cast(), "9.000");
+	CHECK_EQ(formula("4 * (-1.1)").execute().string_cast(), "-4.400");
+}
+
+UNIT_TEST(map_to_maps_FAILS) {
+	CHECK_EQ(formula("{'a' -> ({'b' -> 2})}").execute().string_cast(), formula("{'a' -> {'b' -> 2}}").execute().string_cast());
+}
+
 BENCHMARK(formula_if) {
 	static map_formula_callable* callable = new map_formula_callable;
 	callable->add("x", variant(1));
