@@ -23,11 +23,11 @@ typedef std::string::const_iterator iterator;
 
 enum FFL_TOKEN_TYPE { TOKEN_OPERATOR, TOKEN_STRING_LITERAL,
                   TOKEN_CONST_IDENTIFIER,
-		          TOKEN_IDENTIFIER, TOKEN_INTEGER,
+		          TOKEN_IDENTIFIER, TOKEN_INTEGER, TOKEN_DECIMAL,
                   TOKEN_LPARENS, TOKEN_RPARENS,
 				  TOKEN_LSQUARE, TOKEN_RSQUARE, 
 				  TOKEN_LBRACKET, TOKEN_RBRACKET,
-				  TOKEN_COMMA, TOKEN_SEMICOLON, 
+				  TOKEN_COMMA, TOKEN_SEMICOLON, TOKEN_COLON, 
 				  TOKEN_WHITESPACE, TOKEN_KEYWORD,
 				  TOKEN_COMMENT, TOKEN_POINTER,
 				  TOKEN_INVALID  };
