@@ -1,52 +1,79 @@
 #include "iphone_controls.hpp"
 
-#if TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
+#if TARGET_OS_HARMATTAN || TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
 
 #include <SDL.h>
 
+#ifdef TARGET_OS_HARMATTAN
+#include <math.h> // sqrt
+#endif
+
 #include "foreach.hpp"
 #include "geometry.hpp"
 #include "preferences.hpp"
 #include "raster.hpp"
 #include "texture.hpp"
+#include "wml_parser.hpp"
+#include "wml_utils.hpp"
+#include "formula.hpp"
 
 namespace
 {
-	rect left_arrow, right_arrow, down_arrow, up_arrow, a_button, c_button, interact_button;
+	rect left_arrow, right_arrow, down_arrow, up_arrow, a_button, c_button, interact_button, jumpdown_button, spin_button;
 
-	const int underwater_circle_rad = 120;
-	int underwater_circle_x = 150;
-	int underwater_circle_y = 150; //changed to be relative to the bottom by setup_rects()
+	int underwater_circle_rad, underwater_circle_x, underwater_circle_y;
 
 	bool is_underwater = false;
 	bool can_interact = false;
 	bool on_platform = false;
+	bool is_standing = false;
 	
-	//This is to keep track of whether the rects above have been modified
-	//by modify_rects() yet, to make them work on different resolutions
-	bool done_setup_rects = false;
+	std::string loaded_control_scheme = "";
 	static void setup_rects ()
 	{
-		if (done_setup_rects)
+		const std::string& scheme_name = preferences::control_scheme();
+		if (loaded_control_scheme == scheme_name)
 		{
 			return;
 		}
-		done_setup_rects = true;
+		loaded_control_scheme = scheme_name;
 		
-		int vw = preferences::virtual_screen_width();
-		int vh = preferences::virtual_screen_height();
+		underwater_circle_y = preferences::virtual_screen_height()-underwater_circle_y;
+		
+		wml::node_ptr schemes = wml::parse_wml_from_file("data/control_schemes.cfg");
+		wml::node_ptr scheme = wml::find_child_by_attribute(schemes, "control_scheme", "id", scheme_name);
+		
+		underwater_circle_x = game_logic::formula(wml::get_str(scheme, "underwater_circle_x")).execute().as_int();
+		underwater_circle_y = game_logic::formula(wml::get_str(scheme, "underwater_circle_y")).execute().as_int();
+		underwater_circle_rad = game_logic::formula(wml::get_str(scheme, "underwater_circle_rad")).execute().as_int();
+		
+		FOREACH_WML_CHILD(node, scheme, "button")
+		{
+			variant r = game_logic::formula(wml::get_str(node, "hit_rect")).execute();
+			rect hit_rect(r[0].as_int(), r[1].as_int(), r[2].as_int(), r[3].as_int());
+			std::string id = wml::get_str(node, "id");
+			if (id == "left") {
+				left_arrow = hit_rect;
+			} else if (id == "right") {
+				right_arrow = hit_rect;
+			} else if (id == "up") {
+				up_arrow = hit_rect;
+			} else if (id == "down") {
+				down_arrow = hit_rect;
+			} else if (id == "b") {
+				c_button = hit_rect;
+			} else if (id == "a") {
+				a_button = hit_rect;
+			} else if (id == "interact") {
+				interact_button = hit_rect;
+			} else if (id == "jump_down") {
+				jumpdown_button = hit_rect;
+			} else if (id == "spin") {
+				spin_button = hit_rect;
+			}
+		}
 		
-		left_arrow = rect(0, vh - 200, 10 + 72*2, 200);
-		right_arrow = rect(252, vh - 200, 150 + 72*2, 200);
-		down_arrow = rect(154, vh - 74, 46*2 + 6, 74);
-		up_arrow = rect(154, vh - 264, 46*2 + 6, 80 + 55*2);
-		a_button = rect(vw - 220, vh - 120, 50*2*2 + 20, 60*2);
 //		b_button = rect(vw - 102, vh - 300, 50*2, 60*2);
-		c_button = rect(vw - 144, vh - 360, 50*2 + 40 + 4, 60*2*2);
-		
-		interact_button = rect(vw - 320 - 50, vh - 200, 50*2 + 50, 200);
-		
-		underwater_circle_y = vh-underwater_circle_y;
 	}
 
 	struct Mouse {
@@ -76,6 +103,11 @@ void iphone_controls::read_controls()
 {
 	active_mice.clear();
 
+#ifdef TARGET_OS_HARMATTAN
+	// there is no SDL_Get_NumMice and SDL_SelectMouse support on
+	// Harmattan, so all_mice has been updated via calls to handle_event
+	const int nmice = all_mice.size();
+#else
 	const int nmice = SDL_GetNumMice();
 	if(all_mice.size() > nmice) {
 		all_mice.resize(nmice);
@@ -99,13 +131,38 @@ void iphone_controls::read_controls()
 		all_mice[i].x = x;
 		all_mice[i].y = y;
 		all_mice[i].active = button_state & SDL_BUTTON(SDL_BUTTON_LEFT);
+	}
+#endif
+	for(int i = 0; i < nmice; i++) {
 		if(all_mice[i].active) {
 			active_mice.push_back(all_mice[i]);
 		}
 	}
-	
 }
 
+#ifdef TARGET_OS_HARMATTAN
+void iphone_controls::handle_event (const SDL_Event& event)
+{
+	int x = event.type == SDL_MOUSEMOTION ? event.motion.x : event.button.x;
+	int y = event.type == SDL_MOUSEMOTION ? event.motion.y : event.button.y;
+	int i = event.type == SDL_MOUSEMOTION ? event.motion.which : event.button.which;
+	translate_mouse_coords(&x, &y);
+	while(all_mice.size() <= i) {
+		all_mice.push_back(Mouse());
+		all_mice[i].active = false;
+	}
+
+	if(!all_mice[i].active) {
+		all_mice[i].starting_x = x;
+		all_mice[i].starting_y = y;
+	}
+
+	all_mice[i].x = x;
+	all_mice[i].y = y;
+	all_mice[i].active = event.type != SDL_MOUSEBUTTONUP;
+}
+#endif
+
 void iphone_controls::set_underwater(bool value)
 {
 	is_underwater = value;
@@ -121,6 +178,11 @@ void iphone_controls::set_on_platform(bool value)
 	on_platform = value;
 }
 
+void iphone_controls::set_standing(bool value)
+{
+	is_standing = value;
+}
+
 bool iphone_controls::water_dir(float* xvalue, float* yvalue)
 {
 	setup_rects();
@@ -148,15 +210,17 @@ bool iphone_controls::water_dir(float* xvalue, float* yvalue)
 void iphone_controls::draw()
 {
 	if(!is_underwater) {
-		/*
-		graphics::draw_rect(left_arrow, graphics::color(255, 0, 0, 64));
-		graphics::draw_rect(right_arrow, graphics::color(255, 0, 0, 64));
-		graphics::draw_rect(up_arrow, graphics::color(0, 255, 0, 64));
-		graphics::draw_rect(down_arrow, graphics::color(0, 0, 255, 64));
-		graphics::draw_rect(a_button, graphics::color(255, 0, 0, 64));
-		graphics::draw_rect(c_button, graphics::color(0, 255, 0, 64));
-		graphics::draw_rect(interact_button, graphics::color(0, 0, 255, 64));
-		*/
+		if (preferences::show_iphone_controls())
+		{
+			graphics::draw_rect(left_arrow, graphics::color(255, 0, 0, 64));
+			graphics::draw_rect(right_arrow, graphics::color(255, 0, 0, 64));
+			graphics::draw_rect(up_arrow, graphics::color(0, 255, 0, 64));
+			graphics::draw_rect(down_arrow, graphics::color(0, 0, 255, 64));
+			graphics::draw_rect(a_button, graphics::color(255, 0, 0, 64));
+			graphics::draw_rect(c_button, graphics::color(0, 255, 0, 64));
+			graphics::draw_rect(interact_button, graphics::color(0, 0, 255, 64));
+			graphics::draw_rect(jumpdown_button, graphics::color(255, 0, 255, 64));
+		}
 		return;
 	}
 
@@ -185,7 +249,7 @@ void iphone_controls::draw()
 bool iphone_controls::hittest_button(const rect& area)
 {
 	setup_rects();
-	static graphics::texture tex(graphics::texture::get("gui/iphone_controls.png"));
+	//static graphics::texture tex(graphics::texture::get("gui/iphone_controls.png"));
 	foreach(const Mouse& mouse, active_mice) {
 		const point mouse_pos(mouse.x, mouse.y);
 		if(point_in_rect(mouse_pos, area)) {
@@ -214,7 +278,9 @@ bool iphone_controls::down()
 		return false;
 	}
 
-	return hittest_button(down_arrow);
+	return hittest_button(down_arrow) ||
+		(on_platform && hittest_button(jumpdown_button)) ||
+		(!is_standing && hittest_button(spin_button));
 }
 
 bool iphone_controls::left()
@@ -246,7 +312,7 @@ bool iphone_controls::jump()
 		return false;
 	}
 
-	return hittest_button(preferences::reverse_ab() ? c_button : a_button);
+	return hittest_button(preferences::reverse_ab() ? c_button : a_button) || (on_platform && hittest_button(jumpdown_button));
 }
 
 bool iphone_controls::tongue()
@@ -263,6 +329,7 @@ void iphone_controls::draw() {}
 void iphone_controls::set_underwater(bool value) {}
 void iphone_controls::set_can_interact(bool value) {}
 void iphone_controls::set_on_platform(bool value) {}
+void iphone_controls::set_standing(bool value) {}
 
 bool iphone_controls::water_dir(float* xvalue, float* yvalue) { return false; }
 
