@@ -18,6 +18,9 @@
 #include "foreach.hpp"
 #include "formula_profiler.hpp"
 #include "inventory.hpp"
+#ifdef TARGET_OS_HARMATTAN
+#include "iphone_controls.hpp"
+#endif
 #include "joystick.hpp"
 #include "level_runner.hpp"
 #include "light.hpp"
@@ -315,9 +318,11 @@ bool level_runner::play_cycle()
 		}
 	}
 
-	//record player movement every 500 cycles on average.
-#if !TARGET_OS_IPHONE
-	if(rand()%500 == 0 && lvl_->player()) {
+	//record player movement every 50 cycles on average.
+	//TODO: currently disabled, since this takes up way too much space.
+	//later work out a nicer way to do move events.
+#if !TARGET_OS_HARMATTAN && !TARGET_OS_IPHONE
+	if(false && rand()%50 == 0 && lvl_->player()) {
 		point p = lvl_->player()->get_entity().midpoint();
 
 		if(last_stats_point_level_ == lvl_->id()) {
@@ -498,7 +503,8 @@ bool level_runner::play_cycle()
 	if(message_dialog::get() == NULL) {
 		SDL_Event event;
 		while(SDL_PollEvent(&event)) {
-#if TARGET_IPHONE_SIMULATOR || TARGET_OS_IPHONE
+		//std::cerr << "Got event (level_runner 502): " << (int) event.type << ".\n";
+#if TARGET_IPHONE_SIMULATOR || TARGET_OS_HARMATTAN || TARGET_OS_IPHONE
 			should_pause = settings_dialog.handle_event(event);
 #endif
 			switch(event.type) {
@@ -556,10 +562,24 @@ bool level_runner::play_cycle()
 					}
 				}
 			break;
+#elif TARGET_OS_HARMATTAN
+			// make sure nothing happens while the app is supposed to be "inactive"
+			case SDL_ACTIVEEVENT:
+				if (event.active.state & SDL_APPINPUTFOCUS && event.active.gain == 0)
+				{
+					SDL_Event e;
+					while (SDL_WaitEvent(&e))
+					{
+						if (e.type == SDL_ACTIVEEVENT && e.active.state & SDL_APPINPUTFOCUS && e.active.gain == 1)
+							break;
+					}
+				}
+			break;
 #endif
 			case SDL_KEYDOWN: {
 				const SDLMod mod = SDL_GetModState();
 				const SDLKey key = event.key.keysym.sym;
+				//std::cerr << "Key #" << (int) key << ".\n";
 				if(key == SDLK_ESCAPE) {
 					should_pause = true;
 					break;
@@ -631,6 +651,13 @@ bool level_runner::play_cycle()
 				}
 				break;
 			}
+#ifdef TARGET_OS_HARMATTAN
+			case SDL_MOUSEMOTION:
+			case SDL_MOUSEBUTTONDOWN:
+			case SDL_MOUSEBUTTONUP:
+				iphone_controls::handle_event(event);
+				break;
+#endif
 			default:
 				break;
 			}
@@ -680,7 +707,7 @@ bool level_runner::play_cycle()
 		draw_scene(*lvl_, last_draw_position(), NULL, !is_skipping_game());
 
 		performance_data perf = { current_fps_, current_cycles_, current_delay_, current_draw_, current_process_, current_flip_, cycle, current_events_, profiling_summary_ };
-#if TARGET_IPHONE_SIMULATOR || TARGET_OS_IPHONE
+#if TARGET_IPHONE_SIMULATOR || TARGET_OS_HARMATTAN || TARGET_OS_IPHONE
 		if( ! is_achievement_displayed() ){
 			settings_dialog.draw(in_speech_dialog());
 		}
