@@ -2,9 +2,11 @@
 #ifndef SDL_VIDEO_OPENGL_ES
 #include <GL/glew.h>
 #endif
-#ifdef TARGET_PANDORA
+#if defined(TARGET_OS_HARMATTAN) || defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
 #include <GLES/gl.h>
+#ifdef TARGET_PANDORA
 #include <GLES/glues.h>
+#endif
 #else
 #include <GL/gl.h>
 #include <GL/glu.h>
@@ -21,6 +23,10 @@
 #include <boost/lexical_cast.hpp>
 #include <boost/scoped_ptr.hpp>
 
+#ifdef TARGET_OS_HARMATTAN
+#include <glib-object.h>
+#endif
+
 #include "asserts.hpp"
 #include "controls.hpp"
 #include "custom_object.hpp"
@@ -68,7 +74,7 @@
 #include "wml_utils.hpp"
 #include "wml_writer.hpp"
 
-#if defined(TARGET_PANDORA)
+#if defined(TARGET_PANDORA) | defined(TARGET_TEGRA)
 #include "eglport.h"
 #endif
 
@@ -95,6 +101,7 @@ void print_help(const std::string& argv0)
 "      --level LEVEL_FILE       starts the game using the specified level file,\n" <<
 "                                 relative to the level path\n" <<
 "      --level-path=PATH        sets the path to the game level files\n" <<
+"      --native			        one pixel in-game equals one pixel on monitor." <<
 "      --[no-]music             enables/disables game music\n" <<
 "      --relay                  use the server as a relay in multiplayer rather\n" <<
 "                                 than trying to initiate direct connections\n" <<
@@ -102,7 +109,7 @@ void print_help(const std::string& argv0)
 "      --scale                  enables an experimental pixel art interpolation\n" <<
 "                                 algorithm for scaling the game graphics (some\n" <<
 "                                 issues with this still have to be solved)\n" <<
-"      --no-send-stats          disables sending game statistics over the\n" <<
+"      --[no-]send-stats        enables/disables sending game statistics over the\n" <<
 "                                 network\n" <<
 "      --[no-]sound             enables/disables sound and music support\n" <<
 "      --widescreen             sets widescreen mode, increasing the game view\n" <<
@@ -158,6 +165,9 @@ extern "C" int main(int argc, char** argv)
 		return -1;
 	}
 
+#ifdef TARGET_OS_HARMATTAN
+	g_type_init();
+#endif
 	i18n::init ();
 
 //	SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE, 1);
@@ -304,6 +314,16 @@ extern "C" int main(int argc, char** argv)
 	}
 	
 #else
+#ifdef TARGET_OS_HARMATTAN
+	SDL_GL_SetAttribute(SDL_GL_CONTEXT_MAJOR_VERSION, 1);
+	if (SDL_SetVideoMode(preferences::actual_screen_width(),preferences::actual_screen_height(),0,SDL_OPENGLES | SDL_FULLSCREEN) == NULL) {
+		std::cerr << "could not set video mode\n";
+		return -1;
+	}
+
+	preferences::init_oes();
+	SDL_ShowCursor(0);
+#else
 #ifndef __APPLE__
 	graphics::surface wm_icon = graphics::surface_cache::get("window-icon.png");
 	if(!wm_icon.null()) {
@@ -317,12 +337,24 @@ extern "C" int main(int argc, char** argv)
 		return -1;
 	}
     EGL_Init();
+    preferences::init_oes();
+#else
+#if defined(TARGET_TEGRA)
+	//if (SDL_SetVideoMode(preferences::actual_screen_width(),preferences::actual_screen_height(),0,preferences::resizable() ? SDL_RESIZABLE : 0|preferences::fullscreen() ? SDL_FULLSCREEN : 0) == NULL) {
+	if (SDL_SetVideoMode(preferences::actual_screen_width(),preferences::actual_screen_height(),0,SDL_FULLSCREEN) == NULL) {
+		std::cerr << "could not set video mode\n";
+		return -1;
+	}
+    EGL_Init();
+    preferences::init_oes();
 #else
 	if (SDL_SetVideoMode(preferences::actual_screen_width(),preferences::actual_screen_height(),0,SDL_OPENGL|(preferences::resizable() ? SDL_RESIZABLE : 0)|(preferences::fullscreen() ? SDL_FULLSCREEN : 0)) == NULL) {
 		std::cerr << "could not set video mode\n";
 		return -1;
 	}
 #endif
+#endif
+#endif
 
 #endif
 
@@ -406,20 +438,8 @@ extern "C" int main(int argc, char** argv)
 		return 0;
 	}
 
-	if(run_benchmarks) {
-		if(benchmarks_list.empty() == false) {
-			test::run_benchmarks(&benchmarks_list);
-		} else {
-			test::run_benchmarks();
-		}
-		return 0;
-	} else if(utility_program.empty() == false) {
-		test::run_utility(utility_program, util_args);
-		return 0;
-	}
-
 #if defined(__APPLE__) && !(TARGET_IPHONE_SIMULATOR || TARGET_OS_IPHONE)
-	long swapInterval = 1;
+	GLint swapInterval = 1;
 	CGLSetParameter(CGLGetCurrentContext(), kCGLCPSwapInterval, &swapInterval);
 #endif
 
@@ -428,6 +448,8 @@ extern "C" int main(int argc, char** argv)
 	ASSERT_EQ(glew_status, GLEW_OK);
 #endif
 
+	loader.finish_loading();
+
 	//look to see if we got any quit events while loading.
 	{
 	SDL_Event event;
@@ -441,6 +463,18 @@ extern "C" int main(int argc, char** argv)
 	formula_profiler::manager profiler(profile_output);
 	texture_frame_buffer::init();
 
+	if(run_benchmarks) {
+		if(benchmarks_list.empty() == false) {
+			test::run_benchmarks(&benchmarks_list);
+		} else {
+			test::run_benchmarks();
+		}
+		return 0;
+	} else if(utility_program.empty() == false) {
+		test::run_utility(utility_program, util_args);
+		return 0;
+	}
+
 	bool quit = false;
 	bool of_initialized = false;
 
@@ -504,7 +538,7 @@ extern "C" int main(int argc, char** argv)
 	} //end manager scope, make managers destruct before calling SDL_Quit
 
 //	controls::debug_dump_controls();
-#if defined(TARGET_PANDORA)
+#if defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
     EGL_Destroy();
 #endif
 
@@ -512,6 +546,8 @@ extern "C" int main(int argc, char** argv)
 	
 	preferences::save_preferences();
 	std::cerr << SDL_GetError() << "\n";
+#if !defined(TARGET_OS_HARMATTAN) && !defined(TARGET_TEGRA)
 	std::cerr << gluErrorString(glGetError()) << "\n";
+#endif
 	return 0;
 }
