@@ -1,7 +1,7 @@
 #include <math.h>
 #include <stdlib.h>
 
-#ifdef TARGET_PANDORA
+#if defined(TARGET_OS_HARMATTAN) || defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
 #include <GLES/gl.h>
 #else
 #include <GL/gl.h>
