@@ -10,8 +10,15 @@
    See the COPYING file for more details.
 */
 
+#if defined(TARGET_OS_HARMATTAN) || defined(TARGET_PANDORA) || defined(TARGET_TEGRA)
+#include <GLES/gl.h>
+#ifdef TARGET_PANDORA
+#include <GLES/glues.h>
+#endif
+#else
 #include <GL/gl.h>
 #include <GL/glu.h>
+#endif
 #include <pthread.h>
 
 #include "asserts.hpp"
@@ -76,16 +83,16 @@ namespace {
 	}
 
 	const size_t TextureBufSize = 128;
-	GLuint texture_buf[TextureBufSize];
+	unsigned int texture_buf[TextureBufSize];
 	size_t texture_buf_pos = TextureBufSize;
-	std::vector<GLuint> avail_textures;
+	std::vector<unsigned int> avail_textures;
 	bool graphics_initialized = false;
 
-	GLuint current_texture = 0;
+	unsigned int current_texture = 0;
 
-	GLuint get_texture_id() {
+	unsigned int get_texture_id() {
 		if(!avail_textures.empty()) {
-			const GLuint res = avail_textures.back();
+			const unsigned int res = avail_textures.back();
 			avail_textures.pop_back();
 			return res;
 		}
@@ -123,53 +130,49 @@ namespace {
 
 	bool is_npot_allowed()
     {
-	static bool once = false;
-	static bool npot = true;
-	if (once) return npot;
-	once = true;
+		static bool once = false;
+		static bool npot = true;
+		if (once) return npot;
+		once = true;
 
-	if(preferences::force_no_npot_textures()) {
-		npot = false;
-		return false;
-	}
+		if(preferences::force_no_npot_textures()) {
+			npot = false;
+			return false;
+		}
 
-	const char *supported = reinterpret_cast<const char *>(glGetString(GL_EXTENSIONS));
-	const char *version = reinterpret_cast<const char *>(glGetString(GL_VERSION));
-	const char *vendor = reinterpret_cast<const char *>(glGetString(GL_VENDOR));
+		const char *supported = reinterpret_cast<const char *>(glGetString(GL_EXTENSIONS));
+		const char *version = reinterpret_cast<const char *>(glGetString(GL_VERSION));
+		const char *vendor = reinterpret_cast<const char *>(glGetString(GL_VENDOR));
 
-	std::cerr << "OpenGL version: " << version << "\n";
-	std::cerr << "OpenGL vendor: " << vendor << "\n";
-	std::cerr << "OpenGL extensions: " << supported << "\n";
+		// OpenGL >= 2.0 drivers must support NPOT textures
+		bool version_2 = (version[0] >= '2');
+		npot = version_2;
+		// directly test for NPOT extension
+		if (std::strstr(supported, "GL_ARB_texture_non_power_of_two")) npot = true;
 
-	// OpenGL >= 2.0 drivers must support NPOT textures
-	bool version_2 = (version[0] >= '2');
-	npot = version_2;
-	// directly test for NPOT extension
-	if (std::strstr(supported, "GL_ARB_texture_non_power_of_two")) npot = true;
-
-	if (npot) {
-		// Use some heuristic to make sure it is HW accelerated. Might need some
-		// more work.
-		if (std::strstr(vendor, "NVIDIA Corporation")) {
-			if (!std::strstr(supported, "NV_fragment_program2") ||
-				!std::strstr(supported, "NV_vertex_program3")) {
+		if (npot) {
+			// Use some heuristic to make sure it is HW accelerated. Might need some
+			// more work.
+			if (std::strstr(vendor, "NVIDIA Corporation")) {
+				if (!std::strstr(supported, "NV_fragment_program2") ||
+					!std::strstr(supported, "NV_vertex_program3")) {
+						npot = false;
+				}
+			} else if (std::strstr(vendor, "ATI Technologies")) {
+						// TODO: Investigation note: my ATI card works fine for npot textures as long
+						// as mipmapping is enabled. otherwise it runs slowly. Work out why. --David
+					//if (!std::strstr(supported, "GL_ARB_texture_non_power_of_two"))
+						npot = false;
+			} else if(std::strstr(vendor, "Apple Computer") || std::strstr(vendor, "Imagination Technologies")) {
+				if (!std::strstr(supported, "GL_ARB_texture_non_power_of_two")) {
 					npot = false;
-			}
-		} else if (std::strstr(vendor, "ATI Technologies")) {
-					// TODO: Investigation note: my ATI card works fine for npot textures as long
-					// as mipmapping is enabled. otherwise it runs slowly. Work out why. --David
-				//if (!std::strstr(supported, "GL_ARB_texture_non_power_of_two"))
-					npot = false;
-		} else if(std::strstr(vendor, "Apple Computer") || std::strstr(vendor, "Imagination Technologies")) {
-			if (!std::strstr(supported, "GL_ARB_texture_non_power_of_two")) {
-				npot = false;
+				}
 			}
 		}
-	}
-	if(!npot) {
-		std::cerr << "Using only pot textures\n";
-	}
-	return npot;
+		if(!npot) {
+			std::cerr << "Using only pot textures\n";
+		}
+		return npot;
     }
 
 	std::string mipmap_type_to_string(GLenum type) {
@@ -209,17 +212,17 @@ texture::manager::~manager() {
 
 void texture::clear_textures()
 {
-	std::cerr << "TEXTURES LOADING...\n";
+	//std::cerr << "TEXTURES LOADING...\n";
 	texture_map::lock lck(texture_cache());
 	for(texture_map::map_type::const_iterator i = lck.map().begin(); i != lck.map().end(); ++i) {
 		if(!i->second.id_) {
 			continue;
 		}
 
-		std::cerr << "TEXTURE: '" << i->first << "': " << (i->second.id_->init() ? "INIT" : "UNINIT") << "\n";
+		//std::cerr << "TEXTURE: '" << i->first << "': " << (i->second.id_->init() ? "INIT" : "UNINIT") << "\n";
 	}
 
-	std::cerr << "DONE TEXTURES LOADING\n";
+	//std::cerr << "DONE TEXTURES LOADING\n";
 /*
 	//go through all the textures and clear out the ID's. We only want to
 	//re-initialize each shared ID once.
@@ -386,7 +389,7 @@ namespace {
 threading::mutex id_to_build_mutex;
 }
 
-GLuint texture::get_id() const
+unsigned int texture::get_id() const
 {
 	if(!valid()) {
 		return 0;
@@ -420,7 +423,7 @@ void texture::build_textures_from_worker_threads()
 	id_to_build_.clear();
 }
 
-void texture::set_current_texture(GLuint id)
+void texture::set_current_texture(unsigned int id)
 {
 	if(!id || current_texture == id) {
 		return;
@@ -435,7 +438,7 @@ void texture::set_as_current_texture() const
 	width_multiplier = ratio_w_;
 	height_multiplier = ratio_h_;
 
-	const GLuint id = get_id();
+	const unsigned int id = get_id();
 	if(!id || current_texture == id) {
 		return;
 	}
@@ -449,12 +452,14 @@ void texture::set_as_current_texture() const
 texture texture::get(const std::string& str)
 {
 	texture result = texture_cache().get(str);
+	ASSERT_LOG(result.width() % 2 == 0, "\nIMAGE WIDTH IS NOT AN EVEN NUMBER OF PIXELS:" << str);
+	
 	if(!result.valid()) {
 		key surfs;
 		surfs.push_back(surface_cache::get_no_cache(str));
 		result = texture(surfs);
 		texture_cache().put(str, result);
-		std::cerr << (next_power_of_2(result.width())*next_power_of_2(result.height())*2)/1024 << "KB TEXTURE " << str << ": " << result.width() << "x" << result.height() << "\n";
+		//std::cerr << (next_power_of_2(result.width())*next_power_of_2(result.height())*2)/1024 << "KB TEXTURE " << str << ": " << result.width() << "x" << result.height() << "\n";
 	}
 
 	return result;
@@ -480,14 +485,19 @@ texture texture::get(const std::string& str, const std::string& algorithm)
 
 texture texture::get_palette_mapped(const std::string& str, int palette)
 {
-	std::cerr << "get palette mapped: " << str << "," << palette << "\n";
+	//std::cerr << "get palette mapped: " << str << "," << palette << "\n";
 	std::pair<std::string,int> k(str, palette);
 	texture result = palette_texture_cache().get(k);
 	if(!result.valid()) {
 		key surfs;
 		surface s = surface_cache::get_no_cache(str);
-		surfs.push_back(map_palette(s, palette));
-		result = texture(surfs);
+		if(s.get() != NULL) {
+			surfs.push_back(map_palette(s, palette));
+			result = texture(surfs);
+		} else {
+			std::cerr << "COULD NOT FIND IMAGE FOR PALETTE MAPPING: '" << str << "'\n";
+		}
+
 		palette_texture_cache().put(k, result);
 	}
 
@@ -550,7 +560,7 @@ void texture::rebuild_all()
 {
 	for(std::set<texture::ID*>::iterator i = texture_id_registry().begin();
 	    i != texture_id_registry().end(); ++i) {
-		if((*i)->s.get() != NULL && (*i)->id != GLuint(-1)) {
+		if((*i)->s.get() != NULL && (*i)->id != static_cast<unsigned int>(-1)) {
 			(*i)->build_id();
 		}
 	}
@@ -564,7 +574,7 @@ void texture::unbuild_all()
 	}
 }
 
-texture::ID::ID() : id(GLuint(-1)), width(0), height(0) {
+texture::ID::ID() : id(static_cast<unsigned int>(-1)), width(0), height(0) {
 	texture_id_registry().insert(this);
 }
 
@@ -604,10 +614,10 @@ void texture::ID::build_id()
 
 	if(preferences::use_16bpp_textures()) {
 		std::vector<GLushort> buf(s->w*s->h);
-		const GLuint* src = reinterpret_cast<const GLuint*>(s->pixels);
+		const unsigned int* src = reinterpret_cast<const unsigned int*>(s->pixels);
 		GLushort* dst = &*buf.begin();
 		for(int n = 0; n != s->w*s->h; ++n) {
-			const GLuint p =
+			const unsigned int p =
 			  table_8bits_to_4bits[(*src >> 24)&0xFF] << 28 |
 			  table_8bits_to_4bits[(*src >> 16)&0xFF] << 20 |
 			  table_8bits_to_4bits[(*src >> 8)&0xFF] << 12 |
@@ -645,8 +655,8 @@ void texture::ID::build_id()
 
 void texture::ID::unbuild_id()
 {
-#if !TARGET_IPHONE_SIMULATOR && !TARGET_OS_IPHONE
-	if(id == GLuint(-1) || s) {
+#ifndef SDL_VIDEO_OPENGL_ES
+	if(id == static_cast<unsigned int>(-1) || s) {
 		return;
 	}
 
@@ -667,7 +677,7 @@ void texture::ID::destroy()
 		avail_textures.push_back(id);
 	}
 
-	id = GLuint(-1);
+	id = static_cast<unsigned int>(-1);
 	s = surface();
 }
 
