@@ -11,6 +11,7 @@
 #include "formatter.hpp"
 #include "formula.hpp"
 #include "formula_callable.hpp"
+#include "unit_test.hpp"
 #include "variant.hpp"
 #include "wml_formula_callable.hpp"
 
@@ -23,6 +24,8 @@ std::string variant_type_to_string(variant::TYPE type) {
 		return "null";
 	case variant::TYPE_INT: 
 		return "int";
+	case variant::TYPE_DECIMAL: 
+		return "decimal";
 	case variant::TYPE_CALLABLE: 
 		return "object";
 	case variant::TYPE_CALLABLE_LOADING: 
@@ -256,7 +259,9 @@ const variant& variant::operator=(const variant& v)
 		if(type_ > TYPE_INT) {
 			release();
 		}
-		memcpy(this, &v, sizeof(v));
+
+		type_ = v.type_;
+		value_ = v.value_;
 		if(type_ > TYPE_INT) {
 			increment_refcount();
 		}
@@ -375,6 +380,8 @@ bool variant::as_bool() const
 		return false;
 	case TYPE_INT:
 		return int_value_ != 0;
+	case TYPE_DECIMAL:
+		return decimal_value_ != 0;
 	case TYPE_CALLABLE_LOADING:
 		return true;
 	case TYPE_CALLABLE:
@@ -402,6 +409,33 @@ const std::string& variant::as_string() const
 
 variant variant::operator+(const variant& v) const
 {
+	if(type_ == TYPE_INT && v.type_ == TYPE_INT) {
+		//strictly an optimization -- this is handled below, but the case
+		//of adding two integers is the most common so we want it to be fast.
+		return variant(int_value_ + v.int_value_);
+	}
+
+	if(type_ == TYPE_STRING) {
+		if(v.type_ == TYPE_MAP) {
+			return variant(as_string() + v.as_string());
+		} else if(v.type_ == TYPE_STRING) {
+			return variant(as_string() + v.as_string());
+		}
+
+		std::string s;
+		v.serialize_to_string(s);
+		return variant(as_string() + s);
+	}
+
+	if(v.type_ == TYPE_STRING) {
+		std::string s;
+		serialize_to_string(s);
+		return variant(s + v.as_string());
+	}
+	if(type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL) {
+		return variant(as_decimal() + v.as_decimal());
+	}
+
 	if(type_ == TYPE_INT) {
 		return variant(int_value_ + v.as_int());
 	}
@@ -441,34 +475,24 @@ variant variant::operator+(const variant& v) const
 		}
 	}
 
-	if(type_ == TYPE_STRING) {
-		if(v.type_ == TYPE_MAP) {
-			return variant(as_string() + v.as_string());
-		} else if(v.type_ == TYPE_STRING) {
-			return variant(as_string() + v.as_string());
-		}
-
-		std::string s;
-		v.serialize_to_string(s);
-		return variant(as_string() + s);
-	}
-
-	if(v.type_ == TYPE_STRING) {
-		std::string s;
-		serialize_to_string(s);
-		return variant(s + v.as_string());
-	}
-
 	return variant(as_int() + v.as_int());
 }
 
 variant variant::operator-(const variant& v) const
 {
+	if(type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL) {
+		return variant(as_decimal() - v.as_decimal());
+	}
+
 	return variant(as_int() - v.as_int());
 }
 
 variant variant::operator*(const variant& v) const
 {
+	if(type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL) {
+		return variant(as_decimal() * v.as_decimal());
+	}
+
 	if(type_ == TYPE_LIST) {
 		int ncopies = v.as_int();
 		if(ncopies < 0) {
@@ -491,6 +515,14 @@ variant variant::operator*(const variant& v) const
 
 variant variant::operator/(const variant& v) const
 {
+	if(type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL) {
+		if(v.as_decimal().value() == 0) {
+			throw type_error((formatter() << "divide by zero error").str());
+		}
+
+		return variant(as_decimal() / v.as_decimal());
+	}
+
 	const int numerator = as_int();
 	const int denominator = v.as_int();
 	if(denominator == 0) {
@@ -513,17 +545,32 @@ variant variant::operator%(const variant& v) const
 
 variant variant::operator^(const variant& v) const
 {
+	if( type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL ) {
+		double res = pow( as_decimal().value()/double(VARIANT_DECIMAL_PRECISION),
+		                v.as_decimal().value()/double(VARIANT_DECIMAL_PRECISION));		
+		res *= 1000;
+		return variant(static_cast<int>(res), DECIMAL_VARIANT);
+	}
+
 	return variant(static_cast<int>(pow(static_cast<double>(as_int()), v.as_int())));
 }
 
 variant variant::operator-() const
 {
+	if(type_ == TYPE_DECIMAL) {
+		return variant(-decimal_value_, variant::DECIMAL_VARIANT);
+	}
+
 	return variant(-as_int());
 }
 
 bool variant::operator==(const variant& v) const
 {
 	if(type_ != v.type_) {
+		if(type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL) {
+			return as_decimal() == v.as_decimal();
+		}
+
 		return false;
 	}
 
@@ -540,6 +587,10 @@ bool variant::operator==(const variant& v) const
 		return int_value_ == v.int_value_;
 	}
 
+	case TYPE_DECIMAL: {
+		return decimal_value_ == v.decimal_value_;
+	}
+
 	case TYPE_LIST: {
 		if(num_elements() != v.num_elements()) {
 			return false;
@@ -565,6 +616,9 @@ bool variant::operator==(const variant& v) const
 	case TYPE_CALLABLE: {
 		return callable_->equals(v.callable_);
 	}
+	case TYPE_FUNCTION: {
+		return fn_ == v.fn_;
+	}
 	}
 
 	assert(false);
@@ -579,6 +633,10 @@ bool variant::operator!=(const variant& v) const
 bool variant::operator<=(const variant& v) const
 {
 	if(type_ != v.type_) {
+		if(type_ == TYPE_DECIMAL || v.type_ == TYPE_DECIMAL) {
+			return as_decimal() <= v.as_decimal();
+		}
+
 		return type_ < v.type_;
 	}
 
@@ -595,6 +653,10 @@ bool variant::operator<=(const variant& v) const
 		return int_value_ <= v.int_value_;
 	}
 
+	case TYPE_DECIMAL: {
+		return decimal_value_ <= v.decimal_value_;
+	}
+
 	case TYPE_LIST: {
 		for(size_t n = 0; n != num_elements() && n != v.num_elements(); ++n) {
 			if((*this)[n] < v[n]) {
@@ -653,6 +715,15 @@ void variant::serialize_to_string(std::string& str) const
 	case TYPE_INT:
 		str += boost::lexical_cast<std::string>(int_value_);
 		break;
+	case TYPE_DECIMAL: {
+		int fractional = abs(decimal_value_) % VARIANT_DECIMAL_PRECISION;
+		int integer = (decimal_value_ - fractional) / VARIANT_DECIMAL_PRECISION;
+
+		char buf[256];
+		sprintf(buf, "%d.%03d", integer, fractional);
+		str += buf;
+		break;
+	}
 	case TYPE_CALLABLE_LOADING: {
 		ASSERT_LOG(false, "TRIED TO SERIALIZE A VARIANT LOADING");
 		break;
@@ -703,14 +774,18 @@ void variant::serialize_to_string(std::string& str) const
 		break;
 	}
 	case TYPE_STRING: {
-		const char* delim = "'";
-		if(strchr(string_->str.c_str(), '\'')) {
-			delim = "~";
-		}
+		if(string_->str[0] == '~' && string_->str[string_->str.length()-1] == '~') {
+			str += string_->str;
+		} else {
+			const char* delim = "'";
+			if(strchr(string_->str.c_str(), '\'')) {
+				delim = "~";
+			}
 
-		str += delim;
-		str += string_->str;
-		str += delim;
+			str += delim;
+			str += string_->str;
+			str += delim;
+		}
 		break;
 	}
 	default:
@@ -763,6 +838,11 @@ std::string variant::string_cast() const
 		return "0";
 	case TYPE_INT:
 		return boost::lexical_cast<std::string>(int_value_);
+	case TYPE_DECIMAL: {
+		std::string res;
+		serialize_to_string(res);
+		return res;
+	}
 	case TYPE_CALLABLE_LOADING:
 		return "(object loading)";
 	case TYPE_CALLABLE:
@@ -815,6 +895,9 @@ std::string variant::to_debug_string(std::vector<const game_logic::formula_calla
 	case TYPE_INT:
 		s << int_value_;
 		break;
+	case TYPE_DECIMAL:
+		s << string_cast();
+		break;
 	case TYPE_LIST: {
 		s << "[";
 		for(size_t n = 0; n != num_elements(); ++n) {
@@ -885,3 +968,24 @@ std::string variant::to_debug_string(std::vector<const game_logic::formula_calla
 
 	return s.str();
 }
+
+UNIT_TEST(variant_decimal)
+{
+	variant d(9876, variant::DECIMAL_VARIANT);
+	variant d2(4, variant::DECIMAL_VARIANT);
+	CHECK_EQ(d.as_decimal().value(), 9876);
+	CHECK_EQ(d.as_int(), 9);
+	CHECK_EQ(d.string_cast(), "9.876");
+	CHECK_EQ((d + d2).as_decimal().value(), 9880);
+}
+
+BENCHMARK(variant_assign)
+{
+	variant v(4);
+	std::vector<variant> vec(1000);
+	BENCHMARK_LOOP {
+		for(int n = 0; n != vec.size(); ++n) {
+			vec[n] = v;
+		}
+	}
+}
